
function q=min_integral(f,I,n)
% min_integral - beräknar integralen av f(x) på intervallet I.
%
%   Syntax:
%           q =  min_integral(f,I,n)
%   Argument:
%           f - funktionshandtag: pekar på namnet till en funktionsfil eller
%               till en anonym funktion. T.ex. f=@funk eller f = @(x)sin(x.^2)
%           I - 1x2 matris, anger ett intervall I=[a b]
%           n - positivt heltal, anger antalet delintervall.
%   Returnerar:
%           q - ett tal, ger approximationen av integralen.
%   Beskrivning:
%           Programmet beräknar ett approximativt värde på integralen
%           av f(x) över intervallet I med mittpunktsmetoden.
%   Exempel:
%           q = min_integral(@(x)x.*sin(x),[0 1],100)

    a=I(1);
    b=I(2);
    h=(b-a)/n;

    ...

